/*
 * Copyright (c) 2006 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: WSGraph.java,v 1.3 2006/11/20 18:35:11 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.graph.ws;

import org.xmlpull.infoset.XmlElement;

import edu.indiana.extreme.xbaya.graph.GraphException;
import edu.indiana.extreme.xbaya.graph.GraphFactory;
import edu.indiana.extreme.xbaya.graph.GraphSchema;
import edu.indiana.extreme.xbaya.graph.impl.GraphImpl;
import edu.indiana.extreme.xbaya.util.XMLUtil;

/**
 * @author Satoshi Shirasuna
 */
public class WSGraph extends GraphImpl {

    private XmlElement metadata;

    private XmlElement inputMetadata;

    private XmlElement outputMetadata;

    /**
     * Constructs a WSGraph.
     * 
     * @param factory
     */
    public WSGraph(GraphFactory factory) {
        super(factory);
    }

    /**
     * Returns the metadata.
     * 
     * @return The metadata
     */
    public XmlElement getMetadata() {
        return this.metadata;
    }

    /**
     * Sets metadata.
     * 
     * @param metadata
     *            The metadata to set.
     */
    public void setMetadata(XmlElement metadata) {
        this.metadata = metadata;
    }

    /**
     * Returns the inputMetadata.
     * 
     * @return The inputMetadata
     */
    public XmlElement getInputMetadata() {
        return this.inputMetadata;
    }

    /**
     * Sets inputMetadata.
     * 
     * @param inputMetadata
     *            The inputMetadata to set.
     */
    public void setInputMetadata(XmlElement inputMetadata) {
        this.inputMetadata = inputMetadata;
    }

    /**
     * Returns the outputMetadata.
     * 
     * @return The outputMetadata
     */
    public XmlElement getOutputMetadata() {
        return this.outputMetadata;
    }

    /**
     * Sets outputMetadata.
     * 
     * @param outputMetadata
     *            The outputMetadata to set.
     */
    public void setOutputMetadata(XmlElement outputMetadata) {
        this.outputMetadata = outputMetadata;
    }

    /**
     * @see edu.indiana.extreme.xbaya.graph.impl.GraphImpl#toXML(org.xmlpull.infoset.XmlElement)
     */
    @Override
    protected void toXML(XmlElement graphElement) {
        super.toXML(graphElement);

        graphElement.setAttributeValue(GraphSchema.NS,
                GraphSchema.GRAPH_TYPE_ATTRIBUTE, GraphSchema.GRAPH_TYPE_WS);

        if (this.metadata != null) {
            XmlElement metadataElement = graphElement.addElement(
                    GraphSchema.NS, GraphSchema.GRAPH_METADATA_TAG);
            // Clone the metadata to avoid parent problem because this can be
            // called multiple times.
            metadataElement.addChild(XMLUtil.deepClone(this.metadata));
        }

        if (this.inputMetadata != null) {
            XmlElement metadataElement = graphElement.addElement(
                    GraphSchema.NS, GraphSchema.GRAPH_INPUT_METADATA_TAG);
            // Clone the metadata to avoid parent problem because this can be
            // called multiple times.
            metadataElement.addChild(XMLUtil.deepClone(this.inputMetadata));
        }

        if (this.outputMetadata != null) {
            XmlElement metadataElement = graphElement.addElement(
                    GraphSchema.NS, GraphSchema.GRAPH_OUTPUT_METADATA_TAG);
            // Clone the metadata to avoid parent problem because this can be
            // called multiple times.
            metadataElement.addChild(XMLUtil.deepClone(this.outputMetadata));
        }
    }

    /**
     * @see edu.indiana.extreme.xbaya.graph.impl.GraphImpl#parse(org.xmlpull.infoset.XmlElement)
     */
    @Override
    protected void parse(XmlElement graphElement) throws GraphException {
        super.parse(graphElement);

        XmlElement metadataElement = graphElement
                .element(GraphSchema.GRAPH_METADATA_TAG);
        if (metadataElement != null) {
            for (XmlElement appinfo : metadataElement.requiredElementContent()) {
                this.metadata = appinfo;
                // It should have only one element.
                break;
            }
        }

        XmlElement inputMetadataElement = graphElement
                .element(GraphSchema.GRAPH_INPUT_METADATA_TAG);
        if (inputMetadataElement != null) {
            for (XmlElement appinfo : inputMetadataElement
                    .requiredElementContent()) {
                this.inputMetadata = appinfo;
                // It should have only one element.
                break;
            }
        }

        XmlElement outputMetadataElement = graphElement
                .element(GraphSchema.GRAPH_OUTPUT_METADATA_TAG);
        if (outputMetadataElement != null) {
            for (XmlElement appinfo : outputMetadataElement
                    .requiredElementContent()) {
                this.outputMetadata = appinfo;
                // It should have only one element.
                break;
            }
        }
    }
}
/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2006 The Trustees of Indiana University. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
